from distutils.core import setup

setup(
        name  = 'Mnester',
        version = '1.0.0',
        py_modules = ['Mnester'],
        author = 'Wang',
        author_email = '1973919240@qq.com',
        url = 'http://www.headfirstlabs.com',
        description = 'A simple printer of nester lists',        
        )
